/*
 * Copyright 2020 Netsyms Technologies.
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

var platform_type = "";

var platform_theme = "md";

var app_version = "unknown";

var nw_tray = null;

/**
 * If true and animations are set to "auto", animations should be disabled.
 * @type Boolean
 */
var auto_disable_animations = false;

var openBrowser = function (url) {
    window.open(url);
}

var openSystemBrowser = function (url) {
    window.open(url);
}

var scanBarcode = function (success, error) {
    app.dialog.alert("You can't scan barcodes with this device.", "Sorry!");
}

var scanningBarcode = false;

function setupHTML5BarcodeScanner() {
    $("body").append('<script src="node_modules/@zxing/library/umd/index.min.js"></script>');

    scanBarcode = function (success, error) {
        scanningBarcode = true;
        $("#web-barcode-ui").removeClass("hidden");
        // Stolen from https://zxing-js.github.io/library/examples/multi-camera/
        const codeReader = new ZXing.BrowserMultiFormatReader();
        console.log("Info", 'ZXing code reader initialized');
        codeReader.getVideoInputDevices()
                .then((videoInputDevices) => {
                    if (videoInputDevices.length == 0) {
                        codeReader.reset();
                        $("#web-barcode-ui").addClass("hidden");
                        error("A camera is required to scan barcodes.");
                        return;
                    }
                    selectedDeviceId = videoInputDevices[0].deviceId;

                    codeReader.decodeFromInputVideoDeviceContinuously(selectedDeviceId, 'barcode-viewer', (result, err) => {
                        scanningBarcode = false;
                        if (result) {
                            codeReader.reset();
                            $("#web-barcode-ui").addClass("hidden");
                            success(result.text);
                            return;
                        }
                        if (err && !(err instanceof ZXing.NotFoundException)) {
                            console.error(err);
                            codeReader.reset();
                            $("#web-barcode-ui").addClass("hidden");
                            error(err);
                            return;
                        }
                    });
                })
                .catch((err) => {
                    scanningBarcode = false;
                    console.error(err);
                });
        $("#web-barcode-ui").on("click", function () {
            codeReader.reset();
            scanningBarcode = false;
            $("#web-barcode-ui").addClass("hidden");
        });
    };
}

function setupCordovaBarcodeScanner() {
    scanBarcode = function (success, error) {
        scanningBarcode = true;
        cordova.plugins.barcodeScanner.scan(
                function (result) {
                    scanningBarcode = false;
                    if (!result.cancelled) {
                        success(result.text);
                    }
                },
                function (err) {
                    scanningBarcode = false;
                    if (typeof error == "function") {
                        error(err);
                    }
                },
                {
                    showTorchButton: true,
                    showFlipCameraButton: true,
                    prompt: "Scan barcode",
                    resultDisplayDuration: 0,
                    disableSuccessBeep: false,
                    formats: "QR_CODE,DATA_MATRIX,CODE_39,CODE_93,CODE_128"
                }
        );
    };
}

var getLocation = function (success, error) {
    if ("geolocation" in navigator) {
        navigator.geolocation.getCurrentPosition(function (position) {
            success(position);
        }, function (err) {
            if (typeof error == "function") {
                error(err.message);
            }
        }, {
            enableHighAccuracy: true,
            timeout: 5000,
            maximumAge: 0
        });
    } else {
        if (typeof error == "function") {
            error("Location is unavailable.");
        }
    }
}

var watchLocation = function (success, error) {
    if ("geolocation" in navigator) {
        navigator.geolocation.watchPosition(function (position) {
            success(position);
        }, function (err) {
            if (typeof error == "function") {
                error(err.message);
            }
        }, {
            enableHighAccuracy: true,
            timeout: 5000,
            maximumAge: 0
        });
    } else {
        if (typeof error == "function") {
            error("Location is unavailable.");
        }
    }
}

function getPlatformTheme() {
    if (Framework7.device.ios) {
        return "ios";
    } else if (Framework7.device.macos) {
        // Apple is trending towards one OS for all their crap,
        // let's be ahead of that curve
        return "ios";
    } else if (Framework7.device.nwjs) {
        return "md";
    } else if (Framework7.device.android) {
        return "md";
    } else if (Framework7.device.desktop) {
        return "aurora";
    }
    return "md";
}

function initCordova() {
    platform_type = "cordova";

    // Handle back button to close things
    document.addEventListener("backbutton", handleBackButton, false);
    document.addEventListener("deviceready", function () {
        // Make sure the status bar color is set properly
        applyColorTheme();
    }, false);
    openBrowser = function (url) {
        cordova.InAppBrowser.open(url, '_blank', 'location=yes');
    }

    openExternalBrowser = function (url) {
        window.open(url, '_system', '');
    }

    setTimeout(function () {
        if (typeof device != "undefined" && device.platform != "browser") {
            setupCordovaBarcodeScanner();
        } else {
            setupHTML5BarcodeScanner();
        }
    }, 3000);


    $("#app").on("click", "a[href^='geo:']", function (evt) {
        window.open($(this).attr("href"), "_system");
        evt.preventDefault();
    });
    $("#app").on("click", "a[href^='tel:']", function (evt) {
        window.open($(this).attr("href"), "_system");
        evt.preventDefault();
    });
    $("#app").on("click", "a[href^='mailto:']", function (evt) {
        window.open($(this).attr("href"), "_system");
        evt.preventDefault();
    });
    try {
        navigator.splashscreen.hide();
    } catch (ex) {
        setTimeout(function () {
            try {
                navigator.splashscreen.hide();
            } catch (ex) {
                setTimeout(function () {
                    try {
                        navigator.splashscreen.hide();
                    } catch (ex) {
                        setTimeout(function () {
                            navigator.splashscreen.hide();
                        }, 3000);
                    }
                }, 2000);
            }
        }, 1000);
    }
}

function initNW() {
    platform_type = "nw";

    openBrowser = function (url) {
        nw.Window.open(url, {
            id: url
        }, function (browserwin) {
            // Add menubar so the user can navigate around if they click a link
            var browsermenu = new nw.Menu({type: 'menubar'});
            browsermenu.append(new nw.MenuItem({
                label: "Back",
                click: function () {
                    browserwin.window.history.back();
                }
            }));
            browsermenu.append(new nw.MenuItem({
                label: "Forward",
                click: function () {
                    browserwin.window.history.forward();
                }
            }));
            browsermenu.append(new nw.MenuItem({
                label: "Home",
                click: function () {
                    browserwin.window.location.href = url;
                }
            }));
            browserwin.menu = browsermenu;
        });
    }

    openExternalBrowser = function (url) {
        require('nw.gui').Shell.openExternal(url);
    }

    setupHTML5BarcodeScanner();

    $("#app").on("click", "a[href^='geo:']", function (evt) {
        require('nw.gui').Shell.openExternal($(this).attr("href"));
        evt.preventDefault();
    });
    $("#app").on("click", "a[href^='tel:']", function (evt) {
        require('nw.gui').Shell.openExternal($(this).attr("href"));
        evt.preventDefault();
    });
    $("#app").on("click", "a[href^='mailto:']", function (evt) {
        require('nw.gui').Shell.openExternal($(this).attr("href"));
        evt.preventDefault();
    });
}

function initBrowser() {
    platform_type = "browser";

    openBrowser = function (url) {
        window.open(url);
    }

    openExternalBrowser = function (url) {
        window.open(url);
    }

    setupHTML5BarcodeScanner();

    $("#app").on("click", ".geolink", function (evt) {
        window.open($(this).attr("href"), "_blank");
        evt.preventDefault();
    });
}

function initPlatform() {
    if (typeof cordova !== 'undefined') {
        initCordova();
    } else if (typeof nw !== 'undefined') {
        initNW();
    } else {
        initBrowser();
    }

    platform_theme = getPlatformTheme();

    $.getJSON("package.json", function (data) {
        app_version = data.version;
    });
}